@@ -1,6 +1,6 @@
-def data(casings=[], d_openhole=0.216):
+def data(casings=[], d_openhole=0.216, units='metric'):
     from numpy import asarray
-    dict = {'tin': 20.0, 'ts': 15.0, 'wd': 100.0,  'ddi': 4.0, 'ddo': 4.5, 'dri': 17.716, 'dro': 21.0, 'dfm': 80.0,
+    dict_met = {'tin': 20.0, 'ts': 15.0, 'wd': 100.0,  'ddi': 4.0, 'ddo': 4.5, 'dri': 17.716, 'dro': 21.0, 'dfm': 80.0,
             'q': 794.933, 'lambdal': 0.635, 'lambdac': 43.3, 'lambdacem': 0.7, 'lambdad': 40.0, 'lambdafm': 2.249,
             'lambdar': 15.49, 'lambdaw': 0.6, 'cl': 3713.0, 'cc': 469.0, 'ccem': 2000.0, 'cd': 400.0, 'cr': 464.0,
             'cw': 4000.0, 'cfm': 800.0, 'rhof': 1.198, 'rhod': 7.8, 'rhoc': 7.8, 'rhor': 7.8, 'rhofm': 2.245,
@@ -8,6 +8,19 @@ def data(casings=[], d_openhole=0.216):
             'an': 3100.0, 'bit_n': 1.0, 'dp_e': 0.0, 'thao_o': 1.82, 'beta': 44983 * 10 ** 5, 'alpha': 960 * 10 ** -6,
             'k': 0.3832, 'n': 0.7, 'visc': 0}
 
+    dict_eng = {'tin': 68.0, 'ts': 59.0, 'wd': 328.0, 'ddi': 4.0, 'ddo': 4.5, 'dri': 17.716, 'dro': 21.0, 'dfm': 80.0,
+                'q': 300, 'lambdal': 1.098, 'lambdac': 74.909, 'lambdacem': 1.21, 'lambdad': 69.2, 'lambdafm': 3.89,
+                'lambdar': 26.8, 'lambdaw': 1.038, 'cl': 0.887, 'cc': 0.112, 'ccem': 0.478, 'cd': 0.096, 'cr': 0.1108,
+                'cw': 0.955, 'cfm': 0.19, 'rhof': 9.997, 'rhod': 65.09, 'rhoc': 65.09, 'rhor': 65.09, 'rhofm': 18.73,
+                'rhow': 8.587, 'rhocem': 22.5, 'gt': 0.00403, 'wtg': -8.47*10**-4, 'rpm': 100.0, 'tbit': 6637,
+                'wob': 11240, 'rop': 99.7, 'an': 3100.0, 'bit_n': 1.0, 'dp_e': 0.0, 'thao_o': 1.82, 'beta': 652423,
+                'alpha': 5.33 * 10 ** -4, 'k': 0.3832, 'n': 0.7, 'visc': 0}
+
+    if units == 'metric':
+        dict = dict_met
+    else:
+        dict = dict_eng
+
     if len(casings) > 0:
         od = sorted([x['od'] * 0.0254 for x in casings])
         id = sorted([x['id'] * 0.0254 for x in casings])
@@ -107,7 +120,7 @@ def info(about='all'):
               densities_parameters + '\n' + viscosity_parameters + '\n' + operational_parameters)
 
 
-def set_well(temp_dict, depths, visc_eq=True):
+def set_well(temp_dict, depths, visc_eq=True, units='metric'):
     from math import pi, log
 
     class NewWell(object):
@@ -123,21 +136,36 @@ def set_well(temp_dict, depths, visc_eq=True):
             self.inclination = depths.inclination
             self.dogleg = depths.dogleg
             self.azimuth = depths.azimuth
+            if units != 'metric':
+                self.md = [i / 3.28 for i in self.md]
+                self.tvd = [i / 3.28 for i in self.tvd]
+                self.deltaz = self.deltaz / 3.28
+                self.north = [i / 3.28 for i in self.north]
+                self.east = [i / 3.28 for i in self.east]
 
             # TUBULAR
+            if units == 'metric':
+                d_conv = 0.0254   # from in to m
+            else:
+                d_conv = 0.0254   # from in to m
             self.casings = temp_dict["casings"]  # casings array
-            self.riser = round(temp_dict["wd"] / self.deltaz)  # number of grid cells for the riser
-            self.ddi = temp_dict["ddi"] * 0.0254  # Drill String Inner  Diameter, m
-            self.ddo = temp_dict["ddo"] * 0.0254   # Drill String Outer Diameter, m
-            self.dri = temp_dict["dri"] * 0.0254  # Riser diameter Inner Diameter, m
-            self.dro = temp_dict["dro"] * 0.0254   # Riser diameter Outer Diameter, m
+            self.ddi = temp_dict["ddi"] * d_conv  # Drill String Inner  Diameter, m
+            self.ddo = temp_dict["ddo"] * d_conv   # Drill String Outer Diameter, m
+            self.dri = temp_dict["dri"] * d_conv  # Riser diameter Inner Diameter, m
+            self.dro = temp_dict["dro"] * d_conv   # Riser diameter Outer Diameter, m
 
             # CONDITIONS
-            self.ts = temp_dict["ts"]  # Surface Temperature (RKB), °C
-            self.wd = temp_dict["wd"]  # Water Depth, m
+            if units == 'metric':
+                depth_conv = 1     # from m to m
+                self.ts = temp_dict["ts"]  # Surface Temperature (RKB), °C
+            else:
+                depth_conv = 1/3.28   # from ft to m
+                self.ts = (temp_dict["ts"] - 32) * (5/9)  # Surface Temperature (RKB), from °F to °C
+            self.wd = temp_dict["wd"] * depth_conv  # Water Depth, m
+            self.riser = round(self.wd / self.deltaz)  # number of grid cells for the riser
             self.dsr = self.casings[0, 0]  # Surrounding Space Inner Diameter, m
             self.dsro = sorted([self.dro + 0.03, self.casings[-1, 0] + 0.03])[-1]  # Surrounding Space Outer Diameter, m
-            self.dfm = temp_dict["dfm"]  # Undisturbed Formation Diameter, m
+            self.dfm = temp_dict["dfm"] * d_conv   # Undisturbed Formation Diameter, m
 
             # RADIUS (CALCULATED)
             self.r1 = self.ddi / 2  # Drill String Inner  Radius, m
@@ -150,24 +178,42 @@ def set_well(temp_dict, depths, visc_eq=True):
             self.rfm = self.dfm / 2  # Undisturbed Formation Radius, m
 
             # DENSITIES kg/m3
-            self.rhof = temp_dict["rhof"] * 1000  # Fluid
-            self.rhod = temp_dict["rhod"] * 1000  # Drill Pipe
-            self.rhoc = temp_dict["rhoc"] * 1000  # Casing
-            self.rhor = temp_dict["rhor"] * 1000  # Riser
-            self.rhocem = temp_dict["rhocem"] * 1000  # Cement Sheath
-            self.rhofm = temp_dict["rhofm"] * 1000  # Formation
-            self.rhow = temp_dict["rhow"] * 1000  # Seawater
+            if units == 'metric':
+                dens_conv = 1000     # from sg to kg/m3
+            else:
+                dens_conv = 119.83   # from ppg to kg/m3
+            self.rhof = temp_dict["rhof"] * dens_conv  # Fluid
+            self.rhod = temp_dict["rhod"] * dens_conv  # Drill Pipe
+            self.rhoc = temp_dict["rhoc"] * dens_conv  # Casing
+            self.rhor = temp_dict["rhor"] * dens_conv  # Riser
+            self.rhocem = temp_dict["rhocem"] * dens_conv  # Cement Sheath
+            self.rhofm = temp_dict["rhofm"] * dens_conv  # Formation
+            self.rhow = temp_dict["rhow"] * dens_conv  # Seawater
 
             # OPERATIONAL
-            self.tin = temp_dict["tin"]  # Inlet Fluid temperature, °C
-            self.q = temp_dict["q"] * 0.06  # Flow rate, m^3/h
+            if units == 'metric':
+                self.tin = temp_dict["tin"]  # Inlet Fluid temperature, °C
+                q_conv = 0.06     # from lpm to m^3/h
+                an_conv = 1 / 1500  # from in^2 to m^2
+                wob_conv = 1   # from kN to kN
+                tbit_conv = 1  # from kN*m to kN*m
+                rop_conv = 1    # from m/h to m/h
+            else:
+                self.tin = (temp_dict["tin"] - 32) * (5/9)  # Inlet Fluid temperature, from °F to °C
+                q_conv = 0.2271   # from gpm to m^3/h
+                an_conv = 1 / 1500  # from in^2 to m^2
+                wob_conv = 4.4482 / 1000  # from lbf to kN
+                tbit_conv = 1.356 / 1000  # from lbf*ft to kN*m
+                rop_conv = 1/3.28  # from ft/h to m/h
+
+            self.q = temp_dict["q"] * q_conv  # Flow rate, m^3/h
             self.va = (self.q / (pi * ((self.r3 ** 2) - (self.r2 ** 2)))) / 3600  # Fluid velocity through the annular
             self.vp = (self.q / (pi * (self.r1 ** 2))) / 3600  # Fluid velocity through the drill pipe
             self.rpm = temp_dict["rpm"]  # Revolutions per minute
-            self.tbit = temp_dict["tbit"] # Torque on the bit, kN*m
-            self.wob = temp_dict["wob"]  # Weight on bit, kN
-            self.rop = temp_dict["rop"]  # Rate of Penetration, m/h
-            self.an = temp_dict["an"] / 1550  # Area of the nozzles, m^2
+            self.tbit = temp_dict["tbit"] * tbit_conv  # Torque on the bit, kN*m
+            self.wob = temp_dict["wob"] * wob_conv  # Weight on bit, kN
+            self.rop = temp_dict["rop"] * rop_conv  # Rate of Penetration, m/h
+            self.an = temp_dict["an"] * an_conv   # Area of the nozzles, m^2
             self.bit_n = temp_dict["bit_n"]  # drill bit efficiency
             self.dp_e = temp_dict["dp_e"]  # drill pipe eccentricity
 
@@ -198,26 +244,45 @@ def set_well(temp_dict, depths, visc_eq=True):
                 self.visc_p = self.visc_a = temp_dict["visc"] / 1000
 
             # HEAT COEFFICIENTS
-            self.lambdal = temp_dict["lambdal"]  # Fluid
-            self.lambdac = temp_dict["lambdac"]  # Casing
-            self.lambdacem = temp_dict["lambdacem"]  # Cement
-            self.lambdad = temp_dict["lambdad"]  # Drill Pipe
-            self.lambdafm = temp_dict["lambdafm"]       # Formation
-            self.lambdar = temp_dict["lambdar"]     # Riser
-            self.lambdaw = temp_dict["lambdaw"]     # Seawater
-            self.beta = temp_dict["beta"]  # Fluid Thermal Expansion Coefficient
-            self.alpha = temp_dict['alpha']
-            self.cl = temp_dict["cl"]       # Fluid
-            self.cc = temp_dict["cc"]    # Casing
-            self.ccem = temp_dict["ccem"]     # Cement
-            self.cd = temp_dict["cd"]     # Drill Pipe
-            self.cr = temp_dict["cr"]     # Riser
-            self.cw = temp_dict["cw"]      # Seawater
-            self.cfm = temp_dict["cfm"]       # Formation
+            if units == 'metric':
+                lambda_conv = 1     # from W/(m*°C) to W/(m*°C)
+                c_conv = 1  # from J/(kg*°C) to J/(kg*°C)
+                gt_conv = 1     # from °C/m to °C/m
+                beta_conv = 1   # from Pa to Pa
+                alpha_conv = 1  # from 1/°F to 1/°C
+            else:
+                lambda_conv = 1/1.73     # from BTU/(h*ft*°F) to W/(m*°C)
+                c_conv = 4187.53  # from BTU/(lb*°F) to J/(kg*°C)
+                gt_conv = 3.28*1.8     # from °F/ft to °C/m
+                beta_conv = 6894.76  # from psi to Pa
+                alpha_conv = 1.8  # from 1/°F to 1/°C
+
+            # Thermal conductivity  W/(m*°C)
+            self.lambdal = temp_dict["lambdal"] * lambda_conv  # Fluid
+            self.lambdac = temp_dict["lambdac"] * lambda_conv   # Casing
+            self.lambdacem = temp_dict["lambdacem"] * lambda_conv   # Cement
+            self.lambdad = temp_dict["lambdad"] * lambda_conv   # Drill Pipe
+            self.lambdafm = temp_dict["lambdafm"] * lambda_conv        # Formation
+            self.lambdar = temp_dict["lambdar"] * lambda_conv      # Riser
+            self.lambdaw = temp_dict["lambdaw"] * lambda_conv      # Seawater
+
+            self.beta = temp_dict["beta"] * beta_conv  # isothermal bulk modulus, Pa
+            self.alpha = temp_dict['alpha'] * alpha_conv     # Fluid Thermal Expansion Coefficient, 1/°C
+
+            # Specific heat capacity, J/(kg*°C)
+            self.cl = temp_dict["cl"] * c_conv       # Fluid
+            self.cc = temp_dict["cc"] * c_conv     # Casing
+            self.ccem = temp_dict["ccem"] * c_conv      # Cement
+            self.cd = temp_dict["cd"] * c_conv      # Drill Pipe
+            self.cr = temp_dict["cr"] * c_conv      # Riser
+            self.cw = temp_dict["cw"] * c_conv       # Seawater
+            self.cfm = temp_dict["cfm"] * c_conv        # Formation
+
             self.pr_p = self.visc_p * self.cl / self.lambdal       # Prandtl number
             self.pr_a = self.visc_a * self.cl / self.lambdal  # Prandtl number
-            self.gt = temp_dict["gt"] * self.deltaz  # Geothermal gradient, °C/m
-            self.wtg = temp_dict["wtg"] * self.deltaz  # Seawater thermal gradient, °C/m
+
+            self.gt = temp_dict["gt"] * self.deltaz * gt_conv  # Geothermal gradient, from °C/m to °C/cell
+            self.wtg = temp_dict["wtg"] * gt_conv * self.deltaz  # Seawater thermal gradient, from °C/m to °C/cell
 
 
             # Raise Errors:
