@@ -1,10 +1,12 @@
 import matplotlib.pyplot as plt
 
 
-def profile(temp_distribution, tft=True, tt=False, ta=True, tc=False, tr=False, sr=False):
+def profile(temp_distribution, tft=True, tt=False, ta=True, tc=False, tr=False, sr=False, units='metric'):
 
     # Plotting Temperature PROFILE
     md = temp_distribution.md
+    if units == 'english':
+        md = [i * 3.28 for i in md]
     riser = temp_distribution.riser
     csg = temp_distribution.csgs_reach
     if tft:
@@ -23,12 +25,18 @@ def profile(temp_distribution, tft=True, tt=False, ta=True, tc=False, tr=False,
     if sr:
         # Temp. due to gradient vs Depth
         plt.plot(temp_distribution.tsr, md, c='0.6', ls='-', marker='', label='Surrounding Space')
-    plt.xlabel('Temperature, °C')
-    plt.ylabel('Depth, m')
+    if units == 'metric':
+        plt.xlabel('Temperature, °C')
+        plt.ylabel('Depth, m')
+    else:
+        plt.xlabel('Temperature, °F')
+        plt.ylabel('Depth, ft')
     title = 'Temperature Profile at %1.1f hours' % temp_distribution.time
     plt.title(title)
+    plt.ylim(0, md[-1])     # bottom and top limits
     plt.ylim(plt.ylim()[::-1])  # reversing y axis
     plt.legend()  # applying the legend
+    plt.grid()
     plt.show()
 
 
